#!/bin/sh

#### Set locale ####

LANG="ja_JP.eucJP"
#LANG="ja_JP.ujis"
#LANG="ja_JP.UTF-8"

export LANG

#### Help ####

# Print Help
#./lnl -h

#### Start game ####

./lnl $*
